utils::globalVariables(c(
  "WTDR2D",
  "SEX",
  "AGE",
  "RACE_ETH",
  "FAMINC",
  ".",
  "DR1TKCAL",
  "DR2TKCAL",
  "meanRatio",
  "recall",
  "KCAL",
  "ratio",
  "SEQN",
  "score",
  "ageBracket",
  "count",
  "averages",
  "hei_components_0506",
  "hei_components_0708",
  "hei_components_0910",
  "hei_components_1112",
  "hei_components_1314",
  "hei_components_1516",
  "hei_components_1718",
  "variableList_MCMC",
  "variableList_heiComponents",
  "xVarMax",
  "prop",
  "recalls",
  "kcal",
  "DR1_MONOPOLY",
  "DR2_MONOPOLY",
  "DR1TSFAT",
  "DR2TSFAT",
  "DR1_TFACIDS",
  "DR2_TFACIDS"
))

ignore_unused_imports <- function(){
  utils::globalVariables
  ggpubr::annotate_figure
  shiny::runApp
  shinythemes::shinytheme
  stringr::regex
}
